# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.125
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from helix_platform_api_public_client.models.message_category import MessageCategory  # noqa: E501

class TestMessageCategory(unittest.TestCase):
    """MessageCategory unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMessageCategory(self):
        """Test MessageCategory"""
        # inst = MessageCategory()

if __name__ == '__main__':
    unittest.main()
