# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.125
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import date, datetime
from typing import Optional
from pydantic import BaseModel, Field, StrictStr, constr, validator
from helix_platform_api_public_client.models.intra_day_product_type import IntraDayProductType
from helix_platform_api_public_client.models.nomination_gate_status import NominationGateStatus

class IntraDayNominationGate(BaseModel):
    """
    IntraDayNominationGate
    """
    id: constr(strict=True) = Field(..., description="Virtual ID of a \"Workflow\" in the following format `{recurringWorkflowId}:{executionDay}`  Example: `684df173-4110-4e0d-b364-d2364388afe3:2024-06-01` ")
    product_type: IntraDayProductType = Field(..., alias="productType")
    name: StrictStr = Field(...)
    delivery_day: date = Field(..., alias="deliveryDay", description="One single calendar day, interpreted in **System Time**  - ISO 8601 compliant string in `yyyy-mm-dd` format ")
    mtu: datetime = Field(..., description="The first moment (inclusive) of an MTU period  - theoretically can be sent and received with any zone offset (until it marks the desired **absolute MTU start point** on the timeline) - in practice it is advised to transfer it in UTC timezone (with Z offset, \"Zulu time\") - ISO 8601 compliant string in `yyyy-mm-ddThh:mm:ss.SSSZ` format - only with `XX:00:00`, `XX:15:00`, `XX:30:00` and `XX:45:00` time parts are valid values (depending on MTU size) ")
    status: NominationGateStatus = Field(...)
    next_action_at: Optional[datetime] = Field(None, alias="nextActionAt", description="Date and time with zone information, marks an **absolute point** on the timeline  - theoretically can be sent and received with any zone offset (until it marks the desired **absolute point** on the timeline) - in practice it is advised to transfer it in UTC timezone (with Z offset, \"Zulu time\") - ISO 8601 compliant string in `yyyy-mm-ddThh:mm:ss.SSSZ` format ")
    __properties = ["id", "productType", "name", "deliveryDay", "mtu", "status", "nextActionAt"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> IntraDayNominationGate:
        """Create an instance of IntraDayNominationGate from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> IntraDayNominationGate:
        """Create an instance of IntraDayNominationGate from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return IntraDayNominationGate.parse_obj(obj)

        _obj = IntraDayNominationGate.parse_obj({
            "id": obj.get("id"),
            "product_type": obj.get("productType"),
            "name": obj.get("name"),
            "delivery_day": obj.get("deliveryDay"),
            "mtu": obj.get("mtu"),
            "status": obj.get("status"),
            "next_action_at": obj.get("nextActionAt")
        })
        return _obj


